@@ -4,21 +4,21 @@
 
 package Net::LDAP::Constant;
 
-$VERSION = "0.15";
+our $VERSION = '0.17';
 
 use Exporter qw(import);
 
 my @err2name;
 
 local $_;
-while(<DATA>) {
-  last if /^=cut/;
+while (<DATA>) {
+  last  if /^=cut/;
   my $protocol_const = /^=head2 Protocol Constants/ ... /^=head2/;
-  next unless /^=item\s+(LDAP_\S+)\s+\((.*)\)/;
-  my ($name, $value) = ($1,$2);
+  next  unless /^=item\s+(LDAP_\S+)\s+\((.*)\)/;
+  my ($name, $value) = ($1, $2);
   *{$name} = sub () { $value };
   push @EXPORT_OK, $name;
-  $err2name[$value] = $name if $protocol_const;
+  $err2name[$value] = $name  if $protocol_const;
 }
 
 
@@ -29,7 +29,7 @@ while(<DATA>) {
 sub Net::LDAP::Util::ldap_error_name {
   my $code = 0 + (ref($_[0]) ? $_[0]->code : $_[0]);
 
-  $err2name[$code] || sprintf("LDAP error code %d(0x%02X)",$code,$code);
+  $err2name[$code] || sprintf('LDAP error code %d(0x%02X)', $code, $code);
 }
 
 
@@ -37,17 +37,17 @@ sub Net::LDAP::Util::ldap_error_text {
   my $code = 0 + (ref($_[0]) ? $_[0]->code : $_[0]);
   my $text;
 
-  seek(DATA,0,0);
+  seek(DATA, 0, 0);
   local $/=''; # paragraph mode
   local $_;
   my $n = -1;
-  while(<DATA>) {
-    last if /^=head2/ and ++$n;
-    last if /^=cut/;
-    next if $n;
+  while (<DATA>) {
+    last  if /^=head2/ and ++$n;
+    last  if /^=cut/;
+    next  if $n;
     if (/^=item\s+(LDAP_\S+)\s+\((\d+)\)/) {
-      last if defined $text;
-      $text = '' if $2 == $code;
+      last  if defined $text;
+      $text = ''  if $2 == $code;
     }
     elsif (defined $text) {
       $text .= $_;
@@ -61,7 +61,7 @@ sub Net::LDAP::Util::ldap_error_text {
     $text =~ s/^=(over\s*\d*|back)//msg;
     $text =~ s/ +\n//g;
     $text =~ s/\n\n+/\n\n/g;
-    $text =~ s/\n+\Z/\n/ if defined $text;
+    $text =~ s/\n+\Z/\n/  if defined $text;
   }
 
   return $text;
@@ -224,6 +224,10 @@ The specified entry is a leaf entry
 
 Server encountered a problem while attempting to dereference an alias
 
+=item LDAP_PROXY_AUTHZ_FAILURE (47)
+
+The user bound is not authorized to assume the reuested identity.
+
 =item LDAP_INAPPROPRIATE_AUTH (48)
 
 The server requires the client which had attempted to bind anonymously or
